@@ -618,7 +618,7 @@ class ScrollableBox(sprite):
         self.offset = Vector2(0,0)
 
         if not path:
-            self.cursor = py.Surface((width_cursor,self.rect.height - self.get_max()))
+            self.cursor = py.Surface((width_cursor,self.rect.height - self.get_max()),flags=SRCALPHA)
         else:
             self.cursor = py.transform.scale(py.image.load(path),(width_cursor,self.rect.height - self.get_max()))
 
@@ -640,11 +640,10 @@ class ScrollableBox(sprite):
             """
             decorateur qui ajoute automatiquement le retour de la fonction à la liste
             """
-            
             _sprite = func()
             if sprite in _sprite.__class__.__bases__ or type(_sprite)==sprite:
                 self.sprites.append(_sprite)
-                self.cursor = py.Surface((20,self.rect.height - self.get_max()))
+                self.cursor = py.transform.scale(self.cursor,(self.cursor.get_width(),self.rect.height - self.get_max()))
             else:
                 raise TypeError("You must return a sprite based class to add, type returned was :",type(_sprite))
 
